@@ -5,6 +5,8 @@ from .data_structures import (
     IdefixGrid,
     IdefixVtkDataset,
     IdefixVtkHierarchy,
+    PlutoVtkDataset,
 )
 from .fields import IdefixDmpFieldInfo, IdefixVtkFieldInfo
 from .io import IdefixDmpIOHandler, IdefixVtkIOHandler
+from .loaders import load, load_stretched
